===================
Seed Identity Store
===================

The Seed Identity Store is one of the microservices in the Seed Stack.

The Identity Store has two key responsibilities:

- Store the unique Identity of any end-user created in the Seed system.
- Store the Opt-out or Opt-in status for any end-user in the Seed system.
